@@ -5,9 +5,13 @@ use Test::TAP::Model::Visual;
 
 my $model = Test::TAP::Model::Visual->new_with_tests(glob("t/*.t"));
 
-open STDOUT, "|xmllint --noblanks -> example.html" or die "couldn't pipe to xmllint";
+open STDOUT, ">", "example.html"; #"|xmllint --noblanks -> example.html" or die "couldn't pipe to xmllint";
 
-print Test::TAP::HTMLMatrix->new($model);
+my $v = Test::TAP::HTMLMatrix->new($model);
+
+$v->has_inline_css(1);
+
+print "$v";
 
 print STDERR "open example.html\n";
 
